@@ -23,16 +23,17 @@ fn error_from_signal(
 }
 
 /// A recipe, e.g. `foo: bar baz`
-#[derive(PartialEq, Debug)]
+#[derive(PartialEq, Debug, Clone)]
 pub(crate) struct Recipe<'src, D = Dependency<'src>> {
+  pub(crate) body:         Vec<Line<'src>>,
   pub(crate) dependencies: Vec<D>,
   pub(crate) doc:          Option<&'src str>,
-  pub(crate) body:         Vec<Line<'src>>,
   pub(crate) name:         Name<'src>,
   pub(crate) parameters:   Vec<Parameter<'src>>,
   pub(crate) private:      bool,
   pub(crate) quiet:        bool,
   pub(crate) shebang:      bool,
+  pub(crate) priors:       usize,
 }
 
 impl<'src, D> Recipe<'src, D> {
@@ -113,12 +114,10 @@ impl<'src, D> Recipe<'src, D> {
           message: "evaluated_lines was empty".to_owned(),
         })?;
 
-      let Shebang {
-        interpreter,
-        argument,
-      } = Shebang::new(shebang_line).ok_or_else(|| RuntimeError::Internal {
+      let shebang = Shebang::new(shebang_line).ok_or_else(|| RuntimeError::Internal {
         message: format!("bad shebang line: {}", shebang_line),
       })?;
+
       let tmp = tempfile::Builder::new()
         .prefix("just")
         .tempdir()
@@ -127,26 +126,22 @@ impl<'src, D> Recipe<'src, D> {
           io_error: error,
         })?;
       let mut path = tmp.path().to_path_buf();
-      let suffix = if interpreter.ends_with("cmd") || interpreter.ends_with("cmd.exe") {
-        ".bat"
-      } else if interpreter.ends_with("powershell") || interpreter.ends_with("powershell.exe") {
-        ".ps1"
-      } else {
-        ""
-      };
-      path.push(format!("{}{}", self.name(), suffix));
+
+      path.push(shebang.script_filename(self.name()));
+
       {
         let mut f = fs::File::create(&path).map_err(|error| RuntimeError::TmpdirIoError {
           recipe:   self.name(),
           io_error: error,
         })?;
         let mut text = String::new();
-        // add the shebang
-        if interpreter.ends_with("cmd") || interpreter.ends_with("cmd.exe") {
-          text += "\n";
-        } else {
+
+        if shebang.include_shebang_line() {
           text += &evaluated_lines[0];
+        } else {
+          text += "\n";
         }
+
         text += "\n";
         // add blank lines so that lines in the generated script have the same line
         // number as the corresponding lines in the justfile
@@ -176,16 +171,13 @@ impl<'src, D> Recipe<'src, D> {
       })?;
 
       // create a command to run the script
-      let mut command = Platform::make_shebang_command(
-        &path,
-        &context.search.working_directory,
-        interpreter,
-        argument,
-      )
-      .map_err(|output_error| RuntimeError::Cygpath {
-        recipe: self.name(),
-        output_error,
-      })?;
+      let mut command =
+        Platform::make_shebang_command(&path, &context.search.working_directory, shebang).map_err(
+          |output_error| RuntimeError::Cygpath {
+            recipe: self.name(),
+            output_error,
+          },
+        )?;
 
       if context.settings.positional_arguments {
         command.args(positional);
@@ -210,8 +202,8 @@ impl<'src, D> Recipe<'src, D> {
         Err(io_error) => {
           return Err(RuntimeError::Shebang {
             recipe: self.name(),
-            command: interpreter.to_owned(),
-            argument: argument.map(String::from),
+            command: shebang.interpreter.to_owned(),
+            argument: shebang.argument.map(String::from),
             io_error,
           });
         },
@@ -323,7 +315,7 @@ impl<'src, D> Keyed<'src> for Recipe<'src, D> {
   }
 }
 
-impl<'src> Display for Recipe<'src> {
+impl<'src, D: Display> Display for Recipe<'src, D> {
   fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
     if let Some(doc) = self.doc {
       writeln!(f, "# {}", doc)?;
@@ -339,7 +331,12 @@ impl<'src> Display for Recipe<'src> {
       write!(f, " {}", parameter)?;
     }
     write!(f, ":")?;
-    for dependency in &self.dependencies {
+
+    for (i, dependency) in self.dependencies.iter().enumerate() {
+      if i == self.priors {
+        write!(f, " &&")?;
+      }
+
       write!(f, " {}", dependency)?;
     }
 
@@ -353,7 +350,7 @@ impl<'src> Display for Recipe<'src> {
         }
         match fragment {
           Fragment::Text { token } => write!(f, "{}", token.lexeme())?,
-          Fragment::Interpolation { expression, .. } => write!(f, "{{{{{}}}}}", expression)?,
+          Fragment::Interpolation { expression, .. } => write!(f, "{{{{ {} }}}}", expression)?,
         }
       }
       if i + 1 < self.body.len() {
