@@ -1,10 +1,11 @@
 #[macro_use]
 mod test;
 
-mod common;
-
+mod assert_stdout;
+mod assert_success;
 mod choose;
 mod command;
+mod common;
 mod completions;
 mod conditional;
 mod delimiters;
@@ -28,4 +29,6 @@ mod shebang;
 mod shell;
 mod string;
 mod sublime_syntax;
+mod subsequents;
+mod tempdir;
 mod working_directory;
